@@ -1,5 +1,7 @@
-__version__ = "0.1.24"
+__version__ = "0.1.32"
 
 from alfa_sdk.algorithm import AlgorithmClient
+from alfa_sdk.integration import IntegrationClient
 from alfa_sdk.data import DataClient
+from alfa_sdk.cache import CacheClient
 from alfa_sdk.secrets import SecretsClient
