@@ -4,7 +4,7 @@ from alfa_sdk.secrets import SecretsClient
 from alfa_sdk.resources import (
     Algorithm,
     AlgorithmEnvironment,
-    AlgorithmRelease,
+    Release,
     MetaUnit,
 )
 
@@ -23,7 +23,7 @@ class AlgorithmClient(BaseClient):
         return AlgorithmEnvironment(environment_id, session=self.session)
 
     def get_release(self, release_id):
-        return AlgorithmRelease(release_id, session=self.session)
+        return Release(release_id, session=self.session)
 
     def get_mass_customization_unit(self, environment_id, tag):
         return MetaUnit(environment_id, tag, session=self.session)
@@ -40,17 +40,24 @@ class AlgorithmClient(BaseClient):
         return environment.get_algorithm()
 
     def get_environment_from_context(self):
-        if not self.session.context or "algorithmEnvironmentId" not in self.session.context:
+        if not self.session.context or (
+            "environmentId" not in self.session.context
+            and "algorithmEnvironmentId" not in self.session.context
+        ):
             return None
 
-        environment_id = self.session.context.get("algorithmEnvironmentId")
+        environment_id = self.session.context.get(
+            "environmentId", self.session.context.get("algorithmEnvironmentId")
+        )
         return self.get_environment(environment_id)
 
     def get_active_instance_from_context(self, unit_tag):
         context = self.session.context
-        if not context or "algorithmEnvironmentId" not in context:
-            raise ValidationError(error="No algorithm environment defined.")
-        environment_id = context.get("algorithmEnvironmentId")
+        if not context or (
+            "environmentId" not in context and "algorithmEnvironmentId" not in context
+        ):
+            raise ValidationError(error="No environment defined.")
+        environment_id = context.get("environmentId", context.get("algorithmEnvironmentId"))
 
         meta_unit = self.get_mass_customization_unit(environment_id, unit_tag)
         active_instance = meta_unit.get_active_instance()
@@ -60,9 +67,7 @@ class AlgorithmClient(BaseClient):
 
     def list_algorithms(self):
         params = {"teamId": self.user["teamId"]}
-        return self.session.request(
-            "get", "baas", "/api/Algorithms/getList", params=params
-        )
+        return self.session.request("get", "baas", "/api/Algorithms/getList", params=params)
 
     def list_environments(self, algorithm_id):
         algorithm = self.get_algorithm(algorithm_id)
@@ -89,9 +94,8 @@ class AlgorithmClient(BaseClient):
     #
 
     def store_kpi(self, kpis, entity=None, time=None):
-        run_id = self.session.context.get('algorithmRunId')
+        run_id = self.session.context.get("algorithmRunId")
         environment = self.get_environment_from_context()
         if environment is None:
-            raise ValidationError(error="AlgorithmEnvironmentId is not defined.")
-
+            raise ValidationError(error="EnvironmentId is not defined.")
         return environment.store_kpi(kpis, entity, run_id, time)
