@@ -17,20 +17,25 @@ class Authentication:
     user = None
     token = None
 
-    def __init__(self, credentials={}, *, alfa_env):
-        endpoint = EndpointHelper(alfa_env=alfa_env)
+    def __init__(self, credentials={}, *, alfa_env, alfa_id=None, region=None):
+        endpoint = EndpointHelper(alfa_env=alfa_env, alfa_id=alfa_id, region=region)
         url_core = endpoint.resolve("core")
         self._authenticate(url_core, credentials)
 
     def _authenticate(self, url_core, credentials):
         try:
             token = fetch_token(credentials)
-            self.user = validate_token(url_core, token)
+            cookie = fetch_cookie(credentials)
+            if not token and not cookie:
+                raise TokenNotFoundError()
+            self.user = validate_token(url_core, token, cookie)
+            self.cookie = cookie
             self.token = token
         except:
             client_id, client_secret = fetch_credentials(credentials)
             token = request_oauth_token(url_core, client_id, client_secret)
             self.user = validate_token(url_core, token)
+            self.cookie = None
             self.token = token
 
     def get_token(self):
@@ -40,7 +45,7 @@ class Authentication:
         raise TokenNotFoundError()
 
     def authenticate_request(self, options):
-        return authenticate_request(options, self.token)
+        return authenticate_request(options, self.token, cookie=self.cookie)
 
 
 #
@@ -62,12 +67,12 @@ def fetch_token(credentials={}):
         elif cache and "token" in cache:
             credentials["token"] = cache["token"]
 
-    if "token" not in credentials:
-        raise TokenNotFoundError()
-
     return credentials.get("token")
 
 
+def fetch_cookie(credentials={}):
+    return credentials.get("cookie")
+
 def fetch_credentials(credentials={}):
     if "client_id" not in credentials:
         store = AuthStore.get_group()
@@ -111,13 +116,14 @@ def request_oauth_token(url_core, client_id, client_secret):
     return token
 
 
-def validate_token(url_core, token):
-    if not token:
+def validate_token(url_core, token, cookie=None):
+    if not token and not cookie:
         raise AuthenticationError(error="No tokens were supplied")
 
     url = url_core + "/api/ApiKeyValidators/validateTokenForApp"
     options = {"params": {"appId": ALFA_APP_ID}}
-    options = authenticate_request(options, token)
+    options = authenticate_request(options, token, cookie=cookie)
+
     res = requests.get(url, **options)
     res = res.json()
 
@@ -127,12 +133,15 @@ def validate_token(url_core, token):
     return res
 
 
-def authenticate_request(options, token):
-    if not token:
+def authenticate_request(options, token, *, cookie=None):
+    if not token and not cookie:
         raise TokenNotFoundError()
 
     if "headers" not in options:
         options["headers"] = {}
 
-    options["headers"]["wb-authorization"] = token
+    if token is not None:
+        options["headers"]["wb-authorization"] = token
+    if cookie is not None:
+        options["headers"]["cookie"] = cookie
     return options
