@@ -12,7 +12,7 @@ class AlfaError(Exception):
         self.kwargs = kwargs
 
     def __reduce__(self):
-        return _unpickle_exception, (self.__class__, None, self.kwargs)
+        return _unpickle_exception, (self.__class__, (), self.kwargs)
 
 
 def _unpickle_exception(exception_class, args=(), kwargs={}):
