@@ -9,35 +9,40 @@ from alfa_sdk.common.exceptions import (
     ServiceEnvironmentError,
     SemanticVersionError,
     AlfaConfigError,
+    ValidationError
 )
 
 
 class EndpointHelper:
-    def __init__(self, *, alfa_env):
+    def __init__(self, *, alfa_env, alfa_id=None, region=None):
         resource_path = "/".join(("common", "data", "endpoints.json"))
         file = pkg_resources.resource_string("alfa_sdk", resource_path)
 
-        data = json.loads(file)
+        alfa_id = alfa_id or "public"
+        data = json.loads(file)[alfa_id]
+
         self.services = data["services"]
         self.hostname = data["hostname"]
         self.domain = data["domain"]
         self.alfa_env = alfa_env
+        self.region = region or "eu-central-1"
 
     def resolve(self, service, path=""):
         if service not in self.services:
-            raise UnknownServiceError(
-                service_name=service,
-                known_service_names=", ".join(sorted(self.services.keys())),
-            )
+            known_services = ", ".join(sorted(self.services.keys()))
+            raise UnknownServiceError(service_name=service, known_service_names=known_services)
 
         if self.alfa_env not in self.services[service]:
-            raise ServiceEnvironmentError(
-                service_name=service, environment=self.alfa_env
-            )
+            raise ServiceEnvironmentError(service_name=service, environment=self.alfa_env)
 
-        service_name = self.services[service][self.alfa_env]
-        base_url = self.hostname.format(service=service_name, domain=self.domain)
+        host = self.services[service][self.alfa_env]
+        protocol = "https"
+        if isinstance(host, list):
+            protocol, host = host
 
+        base_url = self.hostname.format(
+            protocol=protocol, host=host, region=self.region, domain=self.domain[self.alfa_env]
+        )
         return "{}{}".format(base_url, path)
 
 
@@ -75,9 +80,7 @@ class AlfaConfigHelper:
         try:
             with zipfile.ZipFile(file_path) as zip:
                 if "alfa.yml" not in zip.namelist():
-                    raise AlfaConfigError(
-                        message=message, error="alfa.yml not found in package"
-                    )
+                    raise AlfaConfigError(message=message, error="alfa.yml not found in package")
 
                 file = zip.read("alfa.yml")
                 return file
@@ -96,9 +99,7 @@ class AlfaConfigHelper:
         except AlfaConfigError:
             raise
         except Exception as err:
-            raise AlfaConfigError(
-                message="Failed to read file from path", error=str(err)
-            )
+            raise AlfaConfigError(message="Failed to read file from path", error=str(err))
 
         try:
             conf = yaml.safe_load(file)
@@ -106,4 +107,3 @@ class AlfaConfigHelper:
             raise AlfaConfigError(message="Failed to parse alfa.yml", error=str(err))
 
         return conf
-
