@@ -11,7 +11,7 @@ from alfa_sdk.common.exceptions import (
     ResourceNotFoundError,
     AuthenticationError,
     AuthorizationError,
-    ValidationError
+    ValidationError,
 )
 
 
@@ -21,11 +21,15 @@ DEFAULT_ALFA_ENV = "prod"
 class Session:
     def __init__(self, credentials={}, *, context=None, **kwargs):
         self.context = fetch_context(context)
-        alfa_env = fetch_alfa_env(kwargs, context=self.context)
+
+        self.alfa_env = fetch_alfa_env(kwargs, context=self.context)
+        self.alfa_id = fetch_setting("alfa_id", kwargs, context=self.context)
+        self.region = fetch_setting("platform_region", kwargs, context=self.context)
         credentials = append_credentials(credentials, self.context)
 
-        self.endpoint = EndpointHelper(alfa_env=alfa_env)
-        self.auth = Authentication(credentials, alfa_env=alfa_env)
+        alfa_config = {"alfa_env": self.alfa_env, "alfa_id": self.alfa_id, "region": self.region}
+        self.endpoint = EndpointHelper(**alfa_config)
+        self.auth = Authentication(credentials, **alfa_config)
 
         options = self.auth.authenticate_request({})
         self.http_session = requests.Session()
@@ -40,11 +44,7 @@ class Session:
         else:
             return res
 
-    def invoke(self, algorithm_id, environment, problem, **kwargs):
-        return_holding_response = kwargs.get("return_holding_response")
-        include_details = kwargs.get("include_details")
-        can_buffer = kwargs.get("can_buffer")
-
+    def invoke(self, function_id, environment, problem, **kwargs):
         if type(problem) is not dict:
             try:
                 problem = json.loads(problem)
@@ -53,6 +53,22 @@ class Session:
 
         #
 
+        function_type = kwargs.get("function_type", "algorithm")
+
+        if function_type == "algorithm":
+            return self.invoke_algorithm(function_id, environment, problem, **kwargs)
+        elif function_type == "integration":
+            return self.invoke_integration(function_id, environment, problem, **kwargs)
+
+        raise ValidationError(error="Unknown type of release provided.")
+
+    def invoke_algorithm(self, algorithm_id, environment, problem, **kwargs):
+        return_holding_response = kwargs.get("return_holding_response")
+        include_details = kwargs.get("include_details")
+        can_buffer = kwargs.get("can_buffer")
+
+        #
+
         body = {
             "algorithmId": algorithm_id,
             "environment": environment,
@@ -63,6 +79,17 @@ class Session:
         }
         return self.request("post", "baas", "/api/Algorithms/submitRequest", json=body)
 
+    def invoke_integration(self, integration_id, environment, problem, **kwargs):
+        function_name = kwargs.get("function_name")
+        return self.request(
+            "post",
+            "ais",
+            "/api/Integrations/{}/environments/{}/functions/{}/invoke".format(
+                integration_id, environment, function_name
+            ),
+            json=problem,
+        )
+
 
 #
 
@@ -104,9 +131,7 @@ def parse_response(res):
                 if error["name"] == "AuthorizationError":
                     raise AuthorizationError(url=url, error=error.get("message"))
 
-            raise RequestError(
-                url=url, status=res.status_code, error=str(data.get("error"))
-            )
+            raise RequestError(url=url, status=res.status_code, error=str(data.get("error")))
 
     #
 
@@ -120,17 +145,7 @@ def parse_response(res):
 
 
 def fetch_alfa_env(configuration={}, *, context={}):
-    store = ConfigStore.get_group("alfa")
-    if "alfa_env" in configuration:
-        alfa_env = configuration.get("alfa_env")
-    elif "alfaEnvironment" in context:
-        alfa_env = context.get("alfaEnvironment")
-    elif "ALFA_ENV" in os.environ:
-        alfa_env = os.environ.get("ALFA_ENV")
-    elif store and "alfa_env" in store:
-        alfa_env = store["alfa_env"]
-    else:
-        alfa_env = DEFAULT_ALFA_ENV
+    alfa_env = fetch_setting("alfa_env", configuration, context=context)
 
     if alfa_env in ["dev", "develop", "development"]:
         alfa_env = "dev"
@@ -147,7 +162,7 @@ def fetch_context(context):
         return context
 
     env_context = os.environ.get("ALFA_CONTEXT")
-    
+
     try:
         env_context = json.loads(env_context)
     except:
@@ -159,6 +174,31 @@ def fetch_context(context):
     return {}
 
 
+def fetch_setting(name, configuration={}, *, context={}):
+    context_names = {
+        "alfa_env": "alfaEnvironment",
+        "alfa_id": "alfaID",
+        "platform_region": "platformRegion",
+    }
+    envvar_names = {
+        "alfa_env": "ALFA_ENV",
+        "alfa_id": "ALFA_ID",
+        "platform_region": "PLATFORM_REGION",
+    }
+    defaults = {"alfa_env": "prod", "alfa_id": "public", "platform_region": "eu-central-1"}
+
+    if name in configuration:
+        return configuration.get(name)
+    if context_names[name] in context:
+        return context.get(context_names[name])
+    if envvar_names[name] in os.environ:
+        return os.environ.get(envvar_names[name])
+    store = ConfigStore.get_group("alfa")
+    if store and name in store:
+        return store[name]
+    return defaults[name]
+
+
 def append_credentials(credentials, context):
     if not isinstance(context, collections.Mapping):
         return credentials
@@ -172,4 +212,7 @@ def append_credentials(credentials, context):
     if "token" in context:
         credentials["token"] = context.get("token")
 
+    if "cookie" in context:
+        credentials["cookie"] = context.get("cookie")
+
     return credentials
